#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 nothunks
version:              0.2.1.0
visibility:           public
id:                   nothunks-0.2.1.0-Kfa8FR08rOvDFeDy7DsGlI
key:                  nothunks-0.2.1.0-Kfa8FR08rOvDFeDy7DsGlI
license:              Apache-2.0
copyright:            2018-2024 Input Output Global Inc (IOG)
maintainer:           Marcin Szamotulski <coot@coot.me>
author:               IOG
synopsis:             Examine values for unexpected thunks
description:
    Long lived application data typically should not contain
    any thunks. This library can be used to examine values for
    unexpected thunks, which can then be used in assertions.
    This can be invaluable in avoiding memory leaks, or tracking
    down existing ones.

category:             Development
abi:                  37164611b8bc6c16434991f95442c6ee
exposed:              True
exposed-modules:      NoThunks.Class
import-dirs:          /usr/lib/ghc-9.6.6/site-local/nothunks-0.2.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/nothunks-0.2.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/nothunks-0.2.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-nothunks
hs-libraries:         HSnothunks-0.2.1.0-Kfa8FR08rOvDFeDy7DsGlI
depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7 ghc-heap-9.6.6
    stm-2.5.1.0 text-2.0.2 time-1.12.2
    vector-0.13.2.0-DH6UT7zpR061zYDIVIbmaS
    wherefrom-compat-0.1.1.1-LZ5h60O6Yz67O4hWOlmnMM

haddock-interfaces:   /usr/share/doc/haskell-nothunks/html/nothunks.haddock
haddock-html:         /usr/share/doc/haskell-nothunks/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

